@@ -8,9 +8,9 @@
 TEST=$(txt2man -h 2> /dev/null)
 [ "$TEST" ] || { echo -e "\nYou need to install txt2man, from https://github.com/mvertes/txt2man.\n"; exit 1; }
 
-T2M_DATE="15 Aug. 2021"
+T2M_DATE="26 Mar 2025"
 T2M_NAME=cbm
-T2M_VERSION=0.3.2
+T2M_VERSION=0.4
 T2M_LEVEL=1
 T2M_DESC="display in real time the network traffic speed"
 
