@@ -5,6 +5,8 @@
   Copyright 2006      Paul Martin <pm@debian.org>
   Copyright 2012      Cyril Brulebois <kibi@debian.org>
   Copyright 2020      daltomi <daltomi@disroot.org>
+  Copyright 2023      Jason Bowen <jbowen@infinitecactus.com>
+  Copyright 2024      David Polverari <david.polverari@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -43,6 +45,11 @@
 #include <net/if.h>
 #include <unistd.h>
 
+// Set the max number of rows (and thus interfaces) to display. The
+// choice of 64 is arbitrary, but less likely to cut off interfaces
+// than the original value of 8.
+#define MAX_ROWS 64
+
 // Externs
 extern int optind, opterr, optopt;
 
@@ -180,13 +187,13 @@ int main(int argc, char **argv) {
 
             // Create the interface table
             VerticalTable interfaceTable(screen);
-            interfaceTable.setColumns(4);
+            interfaceTable.setColumns(6);
             interfaceTable.setActiveStyle(A_BOLD);
             interfaceTable.setActiveRow(1);
             // Position the interface table
             interfaceTable.setPosition(2, 2);
             interfaceTable.setSize(screen.getWidth() - 4,
-                                   8); // TODO
+                                   MAX_ROWS); // TODO
 
             // Create the detail table
             VerticalTable detailTable(screen);
@@ -272,6 +279,14 @@ int main(int argc, char **argv) {
                 interfaceTable.setStyle(3, 0,
                                         COLOR_PAIR(COLOR_HEADING) | A_BOLD);
 
+                interfaceTable.setText (4, 0, "Receive Max");
+                interfaceTable.setStyle(4, 0,
+                                        COLOR_PAIR(COLOR_HEADING) | A_BOLD);
+
+                interfaceTable.setText (5, 0, "Transmit Max");
+                interfaceTable.setStyle(5, 0,
+                                        COLOR_PAIR(COLOR_HEADING) | A_BOLD);
+
                 unsigned index = 1;
                 for (statistics::Reader::Interfaces::const_iterator
                         interface = statisticsReader.getInterfaces().begin();
@@ -296,6 +311,14 @@ int main(int argc, char **argv) {
                                                             + interface->getTransmitSpeed(), bit_mode));
                     interfaceTable.setStyle(3, index, A_NORMAL);
 
+                    interfaceTable.setText(4, index,
+                                            formatBandwidth(interface->getReceiveMax(), bit_mode));
+                    interfaceTable.setStyle(4, index, A_NORMAL);
+
+                    interfaceTable.setText(5, index,
+                                            formatBandwidth(interface->getTransmitMax(), bit_mode));
+                    interfaceTable.setStyle(5, index, A_NORMAL);
+
                     if (index == interfaceTable.getActiveRow()) {
                         // Get the details for the active interface
                         struct ifreq req;
@@ -337,7 +360,7 @@ int main(int argc, char **argv) {
                 // Position the interface table
                 interfaceTable.setPosition(2, 2);
                 interfaceTable.setSize(screen.getWidth() - 4,
-                                       8); // TODO
+                                       MAX_ROWS); // TODO
 
                 // Position the detail table
                 detailTable.setPosition(2, 12); // TODO
