@@ -3,6 +3,7 @@
 
   Copyright 2005-2006 Aaron Isotton <aaron@isotton.com>
   Copyright 2007      brian m. carlson <sandals@crustytoothpaste.ath.cx>
+  Copyright 2024      David Polverari <david.polverari@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -49,12 +50,15 @@ public:
 
     double getReceiveSpeed() const;
     double getTransmitSpeed() const;
+    double getReceiveMax() const;
+    double getTransmitMax() const;
 
 private:
     std::string name_;
     bool updated_;
     Statistics statistics_[2];
     double receiveSpeed_, transmitSpeed_;
+    double receiveMax_, transmitMax_;
 };
 
 class Reader {
